#!/bin/sh

PATH=/sbin:/bin:/usr/bin:/usr/sbin
TMPDIR=/mnt/ramdisk
BACKUPFILE=${TMPDIR}/backuptrackerconfig
VERSIONFILE=../pkgVersion.xml
VERSION=`/usr/bin/tinyxmlparser -x /tracker/conf.d -f ${VERSIONFILE}`
MODEL=`confclient -g system_info_extendedmodelname -p 9 -t Value`
OPENSSLKEY="${MODEL}-${VERSION}"

CONFCLIENT=/usr/sbin/confclient
CDF_BACKUP_OPTION="system_mvaas&system_location&reportpush&server&media&vadp_event_triggerlist&event&di&do&tracker&camctrl_c0_cameraid&uart_i0_baudrate&uart_i1_baudrate"
CDF_BACKUP_OPTION_FILE=${TMPDIR}/backupCDFlist.xml

Create_Backup_File()
{
    cd ../
    local userConfPath=conf.d/usrdef
	local jsonConfPath=conf.d/vca
	local trackerVersionPath=pkgVersion.xml
	local trackerConfigPath=tracker_config.xml
	local sensorCalibrationPath=/etc/conf.d/sensorcalibration_c0_coef.xml
	local sensorCalibrationDefaultPath=/etc/conf.d/sensorcalibration_c0_coef_default.xml
	local hardwareDefinePath=/etc/conf.d/hardware_define.xml
	local imageFeaturePath=/etc/conf.d/config_imagefeature_c0.xml
	local configSystemInfoPath=/etc/conf.d/config_systeminfo.xml
	local configVideoModePath=/etc/conf.d/config_videomode_c0.xml
	local image_cfgs=/etc/conf.d/image_cfgs/c0/etc
	local intrinsics=/mnt/flash2/intrinsics.yml
	local extrinsics=/mnt/flash2/extrinsics.yml
	${CONFCLIENT} -g "${CDF_BACKUP_OPTION}" -t XML -p 7 > ${CDF_BACKUP_OPTION_FILE}
	
	[ ! -d "${userConfPath}" ] || [ ! -d "${jsonConfPath}" ] || ] [ ! -e "${trackerVersionPath}" ] || [ ! -e "${CDF_BACKUP_OPTION_FILE}" ] || [ ! -e "${trackerConfigPath}" ] && return 1

	local allFilePath="${userConfPath} ${jsonConfPath} ${trackerVersionPath} ${CDF_BACKUP_OPTION_FILE} ${trackerConfigPath}"

	if [ -d "${image_cfgs}" ]
	then
		allFilePath="${allFilePath} ${image_cfgs}"
	fi

	if [ ! -f "${intrinsics}" ]
	then
		local intrinsics="${image_cfgs}"/intrinsics.yml
		if [ ! -f "${intrinsics}" ]
		then
			local intrinsics=intrinsic/"${MODEL}"/intrinsics.yml
		fi
	fi

	if [ -f "${intrinsics}" ]
	then
		allFilePath="${allFilePath} ${intrinsics}"
	fi

	if [ -f "${extrinsics}" ]
	then
		allFilePath="${allFilePath} ${extrinsics}"
	fi

	if [ -f "${sensorCalibrationPath}" ]
	then
		allFilePath="${allFilePath} ${sensorCalibrationPath}"
	fi

	if [ -f "${sensorCalibrationDefaultPath}" ]
	then
		allFilePath="${allFilePath} ${sensorCalibrationDefaultPath}"
	fi

	if [ -f "${hardwareDefinePath}" ]
	then
		allFilePath="${allFilePath} ${hardwareDefinePath}"
	fi

	if [ -f "${imageFeaturePath}" ]
	then
		allFilePath="${allFilePath} ${imageFeaturePath}"
	fi

	if [ -f "${configSystemInfoPath}" ]
	then
		allFilePath="${allFilePath} ${configSystemInfoPath}"
	fi

	if [ -f "${configVideoModePath}" ]
	then
		allFilePath="${allFilePath} ${configVideoModePath}"
	fi

	tar jcf - ${allFilePath} | openssl enc -aes-256-cbc -out ${BACKUPFILE} -e -salt -k ${OPENSSLKEY}
    strlog=`ls -l ${BACKUPFILE} | awk -F' ' '{print $5}'`
    return 0   
}

if [ "$1" = "backup" ]
then
	Create_Backup_File
	[ $? -eq 0 ] && {
		echo -ne "Content-type: text/plain\r\n"
        echo -ne "Content-Disposition: attachment; filename=VCA-Configurations-v${VERSION}-$(date +%Y%m%d)\r\n"
		echo -ne "Content-length:${strlog}\r\n\r\n"
		cat $BACKUPFILE>&1
		rm -rf $BACKUPFILE
		rm -rf $CDF_BACKUP_OPTION_FILE
	}
fi
